==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_4_1.tar.xz: opt/mae3xx/app/AppServer/Handlers/Reboot.py <==
# -*- coding: utf-8 -*-

from Handlers import BaseHandler
from Utils import MyTimer

import subprocess
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Reboot(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		
		self.name = 'Reboot'
		self.crontab = '/etc/crontab'
		self.daily_reboot = "%s %s   * * *   root    shutdown -r now\n"

	#=======================================================
	# 
	#=======================================================
	def Get(self, request):
		status = 200
		return self.read_cron(), status

	#=======================================================
	# 
	#=======================================================
	def Post(self, request):

		status = 200
		args = request.json
		if args['operation'] == 'restart':
			timer = MyTimer.MyTimer(3, self.reboot)
		elif args['operation'] == 'shutdown':
			timer = MyTimer.MyTimer(3, self.shutdown)
		timer.start()
		return status
	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200
		self.write_cron(request.json)
		return status
		
	#=======================================================
	# 
	#=======================================================
	def reboot(self):
		print ("reboot")
		self.call(['shutdown', '-r', 'now'])

	#=======================================================
	# 
	#=======================================================
	def shutdown(self):
		print ("shutdown")
		self.call(['shutdown', '-h', 'now'])

	
	#=======================================================
	# 
	#=======================================================
	def read_cron(self):
		
		result = {'time':'', 'use':'no'}
		fd	= open(self.crontab, 'r')
		for line in fd:
			if 'shutdown' in line:
				sline = line.split(' ')
				print(sline)
				result['time'] = '%s00' % (sline[1])
				result['use'] = 'yes'
				break

		print( result)
		return result

	#=======================================================
	# 
	#=======================================================
	def write_cron(self, args):
		
		fd	= open(self.crontab, 'r')
		read_lines = fd.read()
		fd.close()
		
		write_lines = []

		for line in read_lines.split('\n'):
			if 'shutdown' in line or 'MA-E300' in line :
				pass
			else:
				write_lines.append(line)

		if args['use'] == 'yes':
			write_lines.append("#MA-E300 AppServer write.")
			write_lines.append(self.daily_reboot % (0, int(args['time'][:2])))

		print(write_lines)
		fd	= open(self.crontab, 'w')
		fd.write('\n'.join(write_lines))

==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_7_0.tar.xz: opt/mae3xx/app/AppServer/Handlers/Reboot.py <==
# -*- coding: utf-8 -*-

from Handlers import BaseHandler
from Utils import MyTimer

import subprocess
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class Reboot(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		
		self.name = 'Reboot'
		self.crontab = '/etc/crontab'
		self.daily_reboot = "%s %s   * * *   root    shutdown -r now #MA-E300 AppServer write."

	#=======================================================
	# 
	#=======================================================
	def Get(self, request):
		status = 200
		return self.read_cron(), status

	#=======================================================
	# 
	#=======================================================
	def Post(self, request):

		status = 200
		args = request.json
		if args['operation'] == 'restart':
			timer = MyTimer.MyTimer(3, self.reboot)
		elif args['operation'] == 'shutdown':
			timer = MyTimer.MyTimer(3, self.shutdown)
		timer.start()
		return status
	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200
		self.write_cron(request.json)
		return status
		
	#=======================================================
	# 
	#=======================================================
	def reboot(self):
		print ("reboot")
		self.call(['shutdown', '-r', 'now'])

	#=======================================================
	# 
	#=======================================================
	def shutdown(self):
		print ("shutdown")
		self.call(['shutdown', '-h', 'now'])

	
	#=======================================================
	# 
	#=======================================================
	def read_cron(self):
		
		result = {'time':'', 'use':'no'}
		fd	= open(self.crontab, 'r')
		for line in fd:
			if 'shutdown' in line:
				sline = line.split(' ')
				print(sline)
				result['time'] = '%s00' % (sline[1])
				result['use'] = 'yes'
				break

		return result

	#=======================================================
	# 
	#=======================================================
	def write_cron(self, args):
		
		fd	= open(self.crontab, 'r')
		read_lines = fd.read()
		fd.close()
		
		write_lines = []

		for line in read_lines.split('\n'):
			if line:
				if 'shutdown' in line:
					pass
				else:
					write_lines.append(line)

		if args['use'] == 'yes':
			write_lines.append(self.daily_reboot % (0, int(args['time'][:2])))
		write_lines.append('\n')
		fd = open(self.crontab, 'w')
		fd.write('\n'.join(write_lines))
